@@ -32,6 +32,7 @@
 #include <QDialogButtonBox>
 #include <QFile>
 #include <QGroupBox>
+#include <QKeySequence>
 #include <QLineEdit>
 #include <QMessageBox>
 #include <QPushButton>
@@ -127,6 +128,13 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
     Bookmarks::Get().setConfigDir(m_cfg_dir);
     uiDockBookmarks = new DockBookmarks(this);
 
+    // setup some toggle view shortcuts
+    uiDockInputCtl->toggleViewAction()->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_J));
+    uiDockRxOpt->toggleViewAction()->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
+    uiDockFft->toggleViewAction()->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_F));
+    uiDockAudio->toggleViewAction()->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_A));
+    uiDockBookmarks->toggleViewAction()->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_B));
+
     setCorner( Qt::TopLeftCorner, Qt::LeftDockWidgetArea );
     setCorner( Qt::TopRightCorner, Qt::RightDockWidgetArea );
     setCorner( Qt::BottomLeftCorner, Qt::BottomDockWidgetArea );
@@ -196,6 +204,7 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
     connect(uiDockRxOpt, SIGNAL(fmMaxdevSelected(float)), this, SLOT(setFmMaxdev(float)));
     connect(uiDockRxOpt, SIGNAL(fmEmphSelected(double)), this, SLOT(setFmEmph(double)));
     connect(uiDockRxOpt, SIGNAL(amDcrToggled(bool)), this, SLOT(setAmDcr(bool)));
+    connect(uiDockRxOpt, SIGNAL(cwOffsetChanged(int)), this, SLOT(setCwOffset(int)));
     connect(uiDockRxOpt, SIGNAL(agcToggled(bool)), this, SLOT(setAgcOn(bool)));
     connect(uiDockRxOpt, SIGNAL(agcHangToggled(bool)), this, SLOT(setAgcHang(bool)));
     connect(uiDockRxOpt, SIGNAL(agcThresholdChanged(int)), this, SLOT(setAgcThreshold(int)));
@@ -252,6 +261,9 @@ MainWindow::MainWindow(const QString cfgfile, bool edit_conf, QWidget *parent) :
     connect(remote, SIGNAL(newFrequency(qint64)), ui->freqCtrl, SLOT(setFrequency(qint64)));
     connect(remote, SIGNAL(newMode(int)), this, SLOT(selectDemod(int)));
     connect(remote, SIGNAL(newMode(int)), uiDockRxOpt, SLOT(setCurrentDemod(int)));
+    connect(remote, SIGNAL(newSquelchLevel(double)), this, SLOT(setSqlLevel(double)));
+    connect(remote, SIGNAL(newSquelchLevel(double)), uiDockRxOpt, SLOT(setSquelchLevel(double)));
+    connect(uiDockRxOpt, SIGNAL(sqlLevelChanged(double)), remote, SLOT(setSquelchLevel(double)));
 
     // satellite events
     connect(remote, SIGNAL(satAosEvent()), uiDockAudio, SLOT(startAudioRecorder()));
@@ -905,6 +917,7 @@ void MainWindow::selectDemod(QString strModulation)
 void MainWindow::selectDemod(int mode_idx)
 {
     double quad_rate;
+    double cwofs = 0.0;
     float maxdev;
     int filter_preset = uiDockRxOpt->currentFilter();
     int flo=0, fhi=0, click_res=100;
@@ -999,6 +1012,7 @@ void MainWindow::selectDemod(int mode_idx)
         ui->plotter->setDemodRanges(-40000, -100, -5000, 0, false);
         uiDockAudio->setFftRange(0,3000);
         click_res = 100;
+        break;
 
         /* USB */
     case DockRxOpt::MODE_USB:
@@ -1011,7 +1025,8 @@ void MainWindow::selectDemod(int mode_idx)
         /* CW-L */
     case DockRxOpt::MODE_CWL:
         rx->set_demod(receiver::RX_DEMOD_SSB);
-        ui->plotter->setDemodRanges(-10000, -100, -5000, 0, false);
+        cwofs = -uiDockRxOpt->getCwOffset();
+        ui->plotter->setDemodRanges(-5000, -100, 100, 5000, true);
         uiDockAudio->setFftRange(0,1500);
         click_res = 10;
         break;
@@ -1019,7 +1034,8 @@ void MainWindow::selectDemod(int mode_idx)
         /* CW-U */
     case DockRxOpt::MODE_CWU:
         rx->set_demod(receiver::RX_DEMOD_SSB);
-        ui->plotter->setDemodRanges(0, 5000, 100, 10000, false);
+        cwofs = uiDockRxOpt->getCwOffset();
+        ui->plotter->setDemodRanges(-5000, -100, 100, 5000, true);
         uiDockAudio->setFftRange(0,1500);
         click_res = 10;
         break;
@@ -1037,6 +1053,7 @@ void MainWindow::selectDemod(int mode_idx)
     ui->plotter->setClickResolution(click_res);
     ui->plotter->setFilterClickResolution(click_res);
     rx->set_filter((double)flo, (double)fhi, d_filter_shape);
+    rx->set_cw_offset(cwofs);
 
     d_have_audio = ((mode_idx != DockRxOpt::MODE_OFF) && (mode_idx != DockRxOpt::MODE_RAW));
 
@@ -1093,6 +1110,11 @@ void MainWindow::setAmDcr(bool enabled)
     rx->set_am_dcr(enabled);
 }
 
+void MainWindow::setCwOffset(int offset)
+{
+    rx->set_cw_offset(offset);
+}
+
 /**
  * @brief Audio gain changed.
  * @param value The new audio gain in dB.
